/*
 * QuickTime for Java SDK Sample Code

   Usage subject to restrictions in SDK License Agreement
 * Copyright:  1996-1999 Apple Computer, Inc.

 */
package MyPlayMovie;

import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import java.io.IOException;

import quicktime.*;
import quicktime.io.*;
import quicktime.std.movies.*;
import quicktime.util.QTUtils;
import quicktime.app.display.QTCanvas;
import quicktime.app.players.QTPlayer;

// This example shows using QT without the layout manager
// The movie is automatically resized to the size of the window
// by intercepting the setBounds call on the window
public class PlayMovie extends Frame implements WindowListener {	

	public static void main (String args[]) {
		PlayMovie pm = new PlayMovie("QT in Java",null);
		pm.show();
		pm.toFront();
	}

	public PlayMovie (String title,QTFile qtf) {
		super (title);
		try { 
			if (qtf == null)
			{
				QTSession.open();
				qtf = QTFile.standardGetFilePreview(QTFile.kStandardQTFileTypes);
			}

			myQTCanvas = new QTCanvas();
			add(myQTCanvas);
		
			OpenMovieFile movieFile = OpenMovieFile.asRead(qtf);
			MovieController mc = new MovieController (Movie.fromFile (movieFile));
			mc.setKeysEnabled (true);

			addNotify();
			Insets insets = getInsets();
			setBounds (0, 0, (insets.left + insets.right + mc.getBounds().getWidth()), (insets.top + insets.bottom + mc.getBounds().getHeight()));
			
			myQTPlayer = new QTPlayer (mc);
			myQTCanvas.setClient (myQTPlayer, true);

			addWindowListener(this);
		} catch (Exception e) {
			e.printStackTrace();
			QTSession.close();
		}
	}

	private QTPlayer myQTPlayer;
	private QTCanvas myQTCanvas;
	
	public void setBounds (int x, int y, int w, int h) {
		super.setBounds (x, y, w, h);
		myQTCanvas.setBounds (x, y, w, h);
	}

	public void windowClosing (WindowEvent e) {
		myQTCanvas.removeClient();
		QTSession.close();
		dispose();
	}

	public void windowIconified (WindowEvent e) {
		try { 
			myQTPlayer.setRate (0); 
		} catch (Exception ex) {}
		myQTPlayer.getTasker().stop();
	}
	
	public void windowDeiconified (WindowEvent e) {
		myQTPlayer.getTasker().start();
	}
	
	public void windowClosed (WindowEvent e) { 
		System.exit(0);
	}
	
	public void windowOpened (WindowEvent e) {
	}
	public void windowActivated (WindowEvent e) {}
	public void windowDeactivated (WindowEvent e) {}
}
